#
# spec file for package forgejo-guardian
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           forgejo-guardian
Version:        0.7.0
Release:        1.1
Summary:        Simple Forgejo instance guardian
License:        AGPL-3.0-or-later
URL:            https://git.4rs.nl/awiteb/forgejo-guardian
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        %{name}.service
Source3:        %{name}.config.example.toml
BuildRequires:  cargo-packaging
Requires:       forgejo >= 10.0.0
%{?systemd_requires}

%description
Simple Forgejo instance guardian, banning users and alerting admins based on
certain regular expressions (regex)

%prep
%autosetup -a1
cp %{SOURCE3} .

%build
%{cargo_build}

%install
install -d %{buildroot}%{_sysconfdir}/%{name}
install -Dm0755 ./target/release/%{name} %{buildroot}%{_bindir}/%{name}
install -Dm0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license LICENSE
%doc README.md DCO %{name}.config.example.toml
%{_bindir}/%{name}
%{_unitdir}/%{name}.service
%dir %{_sysconfdir}/%{name}

%changelog
* Tue Feb 25 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.7.0:
  * A notice if the sus user is active
  * Check the existing users for the sus expressions
  * Lazy purge
  * Retry when Matrix bot stops
  * Change the bot message if the ban is immediately or added to the queue
  * Move inactive.check_tokens|check_oauth2 to global scope
  * Store last 7 users in updated_users fetcher
  * Prevent mutiple alerts for the same user update
* Wed Feb 19 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.6.0:
  * Add German translation
  * Add safe_mode to prevent banning active users and notify moderation team
  * Add support for Matrix bot alongside Telegram bot
  * Don't send alerts of ignored users
  * Option to hide users email
  * Update fetcher to fetch updated users
  * bot command to ban a user
  * New local not_specified used for the regex reason
  * Rename only_new_users to check_existing_users
  * Rename expressions.only_new_users to expressions.check_existing_users
  * Fetch all new users instead of only the first page
* Sat Feb  1 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.5.1:
  * Enhance ban/sus logs to display the location
* Tue Jan 28 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.5.0:
  * Ability to check user tokens and oauth2 apps
  * The minimum value for inactive.req_limit changed to 4
  * Ability to enter seconds in the interval without s suffix
  * Make expressions.interval suffixably
  * Guardian checks all instance users when expressions.only_new_users is false
  * Prevent async deadlock when Telegram is disabled
* Wed Jan 22 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.4.1:
  * Add support for including and excluding users
  * Check for the user activities for more than last 365 days
  * Exceed inactive.req_limit due to asynchronous user checking
- update to 0.4.0:
  * Ability to Enable/disable sus and ban expressions, and Telegram bot
  * Ability to fetch Forgejo token from environment variables
  * Clean up instance of inactive users
  * Move unglobal fields to the expressions section
* Sat Jan 18 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.3.1:
  * Ability to suspend the user instead of deleting them permanently
* Thu Jan 16 2025 Richard Rahl <rrahl0@opensuse.org>
- initial packaging
